@@ -30,48 +30,56 @@ shapefile_list <- function(name, get.data = FALSE) {
          glacier = "ggOceanMapsData::arctic_glacier",
          bathy = "ggOceanMapsData::arctic_bathy",
          crs = 3995,
+         limits = 30,
          path = NA),
     list(name = "AntarcticStereographic", 
          land = "ggOceanMapsData::antarctic_land",
          glacier = "ggOceanMapsData::antarctic_glacier",
          bathy = "ggOceanMapsData::antarctic_bathy",
          crs = 3031,
+         limits = -35,
          path = NA),
     list(name = "DecimalDegree", 
          land = "ggOceanMapsData::dd_land",
          glacier = "ggOceanMapsData::dd_glacier",
          bathy = "ggOceanMapsData::dd_bathy",
          crs = 4326,
+         limits = c(-180, 180, -90, 90),
          path = NA),
     list(name = "Svalbard",
          land = "svalbard_land",
          glacier = "svalbard_glacier",
          bathy = "svalbard_bathy",
          crs = 32633,
+         limits = c(402204.7, 845943.9, 8253526.1, 8978517.5),
          path = "https://github.com/MikkoVihtakari/ggOceanMapsLargeData/raw/master/data/svalbard.rda"),
     list(name = "BarentsSea",
          land = "barentssea_land",
          glacier = "barentssea_glacier",
          bathy = "barentssea_bathy",
          crs = 32636,
+         limits = c(-400000, 1300000, 7400000, 9350000),
          path = "https://github.com/MikkoVihtakari/ggOceanMapsLargeData/raw/master/data/barentssea.rda"),
     list(name = "IBCAO",
          land = "ggOceanMapsData::arctic_land", 
          glacier = "ggOceanMapsData::arctic_glacier",
          bathy = "ibcao_bathy",
          crs = 3995,
+         limits = c(-2879810, 2700490, -2879810, 2879810),
          path = "https://github.com/MikkoVihtakari/ggOceanMapsLargeData/raw/master/data/ibcao_bathy.rda"),
     list(name = "GEBCO",
          land = "ggOceanMapsData::arctic_land", 
          glacier = "ggOceanMapsData::arctic_glacier",
          bathy = "gebco_bathy",
          crs = 3995,
+         limits = 30,
          path = "https://github.com/MikkoVihtakari/ggOceanMapsLargeData/raw/master/data/gebco_bathy.rda"),
     list(name = "EMODnet",
          land = "emodnet_land", 
          glacier = NA,
          bathy = "emodnet_bathy",
          crs = 3575,
+         limits = c(-3e5, -1e5, -3.1e6, -2.9e6),
          path = "https://github.com/MikkoVihtakari/ggOceanMapsLargeData/raw/master/data/emodnet.rda")
   )
 
